@@ -72,11 +72,6 @@ static int set_aspect(int x, int y)
 
 static void adjust_window_size(void)
 {
-     static int old_x = 0;
-     static int old_y = 0;
-     static int old_w = 0;
-     static int old_h = 0;
-
      int x = 0;
      int y = 0;
      int w = windata.width;
@@ -117,18 +112,8 @@ static void adjust_window_size(void)
      }
   
      D("New size: %dx%d+%d+%d\n", w, h, x, y);
-
-     /* Hack to get X to actually resize the window when mozplugger
-      * resizes it two times with the same dimensions. */
-     if (old_x == x && old_y == y && old_h == h && old_w == w)
-	  XMoveResizeWindow(display, victim, x, y, w, h+1);
      
      XMoveResizeWindow(display, victim, x, y, w, h);
-     
-     old_x = x;
-     old_y = y;
-     old_h = h;
-     old_w = w;
 }
 
 /*****************************************************************************
@@ -600,6 +585,8 @@ int main(int argc, char **argv)
        file,
        command);
 
+     if (repeats < 1) repeats = 1;
+
      while (repeats > 0)
      {
 	  char *argv[10];
