@@ -761,7 +761,7 @@ static int match_mime_type(NPP instance, mimetype_t *m)
      sscanf(mimetype, "%s", mimetype);
 
      D("Checking '%s' ?= '%s'\n", mimetype, THIS->mimetype);
-     if (strcasecmp(mimetype, THIS->mimetype))
+     if (strcasecmp(mimetype, THIS->mimetype) && strcmp(mimetype,"*"))
      {
 	  D("Not same.\n");
 	  return 0;
@@ -895,7 +895,7 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 	  D("GET Plugin name\n");
 	  *((char **)value) = "MozPlugger "
 	       VERSION
-	       " handles QuickTime Windows Media Player Plugin"
+	       " handles QuickTime and Windows Media Player Plugin"
 	       ;
 	  break;
 
